--
-- DisableObjects - HardPoint
--
-- @author:    	Xentro (Marcus@Xentro.se)
-- @website:	www.Xentro.se
-- @history:	v1.0 - 2016-08-02 - Initial implementation
-- 

DisableObjects = {};

function DisableObjects:prerequisitesPresent(specializations)
	return true;
end;

-- pre check before attaching
function DisableObjects:allowAdding(vehicle, attaching, object) -- future ,locationID, objectID
	return true;
end;

function DisableObjects:load(xmlFile)
	self.changedIds = {};
	local i = 0;
	while true do
		local key = string.format("vehicle.restrictObjects.object(%d)", i);
		if not hasXMLProperty(xmlFile, key) then break; end;
		
		local id = getXMLInt(xmlFile, key .. "#id");
		if id ~= nil then
			local parent = self.vehicle.hardPointObjects;
			
			if parent[id] ~= nil then
				local state = Utils.getNoNil(getXMLBool(xmlFile, key .. "#allow"), false);
				parent[id].showInStore = state;
				
				self.changedIds[id] = state;
			else
				print("DisableObjects - Error: Invalid restrictObject id " .. id);
			end;
		end;
		
		i = i + 1;
	end;
	
	local defaultIds = {};
	local i = 0;
	while true do
		local key = string.format("vehicle.restrictObjects.default(%d)", i);
		if not hasXMLProperty(xmlFile, key) then break; end;
		
		local locationID = getXMLInt(xmlFile, key .. "#locationID");
		local id = getXMLInt(xmlFile, key .. "#objectID");
		if locationID ~= nil and id ~= nil then
			if self.vehicle.hardPoints[locationID] ~= nil and self.vehicle.hardPointObjects[id] ~= nil then
				defaultIds[locationID] = id;
			else
				print("DisableObjects - Error: Invalid locationID or objectID");
			end;
		end;
		
		i = i + 1;
	end;
	
	for k, v in pairs(self.vehicle.activeHardpoints) do
		local id = v.object.id;
		
		if self.changedIds[id] ~= nil and not self.changedIds[id] then
			if g_currentMission.HardPoint ~= nil then
				g_currentMission.HardPoint:updateList(1, self.vehicle.configFileName, id, 1);
				local num = g_currentMission.HardPoint:getListObject(1, self.vehicle.configFileName, defaultIds[v.locationId]);
				
				if num > 0 then
					g_currentMission.HardPoint:updateList(1, self.vehicle.configFileName, defaultIds[v.locationId], -1);
				else
					g_currentMission.HardPoint:updateList(2, self.vehicle.configFileName, defaultIds[v.locationId], 1);
					if g_client ~= nil then
						local buyAndSellObjectEvent = _G["HardPointExtension"]["buyAndSellObjectEvent"];
						g_client:getServerConnection():sendEvent(buyAndSellObjectEvent:new(true, v.object.price));
					end;
				end;
			end;
			
			self.vehicle:createObject(v.locationId, defaultIds[v.locationId]);
		end;
	end;
end;

function DisableObjects:delete()
	for id in pairs(self.changedIds) do
		self.vehicle.hardPointObjects[id].showInStore = true;
	end;
end;

function DisableObjects:readStream(streamId, connection)
end;

function DisableObjects:writeStream(streamId, connection)
end;

function DisableObjects:update(dt)
end;

function DisableObjects:updateTick(dt)
end;

function DisableObjects:draw()
end;
